Other Resources
===============

This is a collection of some other varied Avocado related sources on
the web:

Presentations
-------------

* `Testing Framework Internals (DevConf 2017) <https://www.youtube.com/watch?v=--fxmmJ5SBA&list=PLpLgrCSz067ao8NsOHdaYtq-06SmBMOBR>`__
* `Auto Testing for AArch64 Virtualization (Linaro connect San Francisco 2017) <http://connect.linaro.org/resource/sfo17/sfo17-502/>`__
* `libvirt integration and testing for enterprise KVM/ARM (Linaro Connect Budapest 2017) <http://connect.linaro.org/resource/bud17/bud17-213/>`__
* `Automated Testing Framework (PyCon CZ 2016) <https://www.youtube.com/watch?v=eTR-LvW80pM&list=PLpLgrCSz067ao8NsOHdaYtq-06SmBMOBR&index=2>`__
* `Avocado and Jenkins (DevConf 2016) <https://www.youtube.com/watch?v=XJ7IWQflM9g&list=PLpLgrCSz067ao8NsOHdaYtq-06SmBMOBR&index=4>`__
* `Avocado: Next Gen Testing Toolbox (DevConf 2015) <https://www.youtube.com/watch?v=xMXS7NB4WSs&index=5&list=PLpLgrCSz067ao8NsOHdaYtq-06SmBMOBR>`__
* Avocado workshop (DevConf 2015) `mindmap with all commands/content <https://www.mindmeister.com/504616310/avocado-workshop>`__ and `a partial video <https://www.mindmeister.com/504616310/avocado-workshop>`__
* `Avocado: Open Source Testing Made Easy (LinuxCon 2015) <https://www.youtube.com/watch?v=tdEg07BfdBw&index=3&list=PLpLgrCSz067ao8NsOHdaYtq-06SmBMOBR>`__


Public test repositories
------------------------

* `Avocado Misc Tests <https://github.com/avocado-framework-tests/avocado-misc-tests>`__
* `Cockpit tests <https://github.com/cockpit-project/cockpit/tree/master/test/avocado>`__
* `Modularity framework tests (uses custom docker image) <https://github.com/fedora-modularity/meta-test-family>`__
* `OpenPOWER Host OS and Guest Virtual Machine (VM) stability tests <https://github.com/open-power-host-os/>`__
